@@ -8,7 +8,7 @@ urlpatterns = patterns(
     '',
     url(r'^pay-now/$', views.PaymentView.as_view(),
         name='asiapay_pay_now'),
-    url(r'^pay-now/(?P<pk>\d+)/$', views.PaymentView.as_view(),
+    url(r'^pay-now/(?P<number>\d+)/$', views.PaymentView.as_view(),
         name='asiapay_pay_now'),
     url(r'^data-feed/$', views.DataFeedView.as_view(),
         name='asiapay_data_feed'),
